@@ -1,6 +1,7 @@
 """
 Useful extensions for standard library
 """
+from enum import Enum
 from typing import Any, Sequence, Tuple, TypeVar, Union
 
 T = TypeVar('T')
@@ -15,3 +16,10 @@ def sequence_or_its_only_member(sequence: Sequence[T]) -> Union[Sequence[T], T]:
 
 def i_removed(tuple_: Tuple[Any, ...], index: Any) -> Tuple[Any, ...]:
     return tuple_[:index] + tuple_[index + 1:]
+
+
+class DefaultType(Enum):
+    DEFAULT = 'default'
+
+
+Default = DefaultType.DEFAULT
